{#- OZI
# ozi/templates/project.name/__init__.py.j2
# SPDX-License-Identifier: MIT-0
-#}
"""{{ project.name|underscorify|lower }} module"""
{% for line in project.copyright_head.split('\n') %}{{ '# ' ~ line }}
{% endfor %}
{%- if user_template -%}
{% extends user_template %}
{%- endif %}

