{#- OZI
# ozi/templates/project.name/new_module.py.j2
# SPDX-License-Identifier: MIT-0
-#}
{% for line in project.copyright_head.split('\n') %}{{'# ' ~ line }}
{% endfor %}
{%- if user_template -%}
{% extends user_template %}
{%- endif %}

